@@ -29,9 +29,6 @@ This manual page documents briefly the
 and
 .B bar
 commands.
-This manual page was written for the Debian distribution
-because the original program does not have a manual page.
-Instead, it has documentation in the GNU Info format; see below.
 .PP
 .\" TeX users may be more comfortable with the \fB<whatever>\fP and
 .\" \fI<whatever>\fP escape sequences to invode bold face and italics, 
@@ -56,5 +53,7 @@ The programs are documented fully by
 .IR "The Rise and Fall of a Fooish Bar" ,
 available via the Info system.
 .SH AUTHOR
+#PACKAGE# was written by <upstream author>.
+.PP
 This manual page was written by #USERNAME# <#EMAIL#>,
 for the Debian project (but may be used by others).
